@@ -12,5 +12,6 @@
 #  You should have received a copy of the GNU General Public License along with Firefly. If not, see
 #  <http://www.gnu.org/licenses/>.
 
-from .abstract_email_service import AbstractEmailService
+from .email_service import EmailService
+from .email_service_factory import EmailServiceFactory
 from .mailchimp_email_service import MailchimpEmailService
